@@ -1,7 +1,6 @@
 import genshi
 
 from ckan.lib.base import *
-from simplejson import dumps
 import ckan.authz as authz
 import ckan.forms
 from ckan.lib.helpers import Page
@@ -20,7 +19,7 @@ class GroupController(BaseController):
             page=request.params.get('page', 1),
             items_per_page=20
         )
-        return render('group/index')
+        return render('group/index.html')
 
     def read(self, id):
         c.group = model.Group.by_name(id)
@@ -45,7 +44,7 @@ class GroupController(BaseController):
             page=request.params.get('page', 1),
             items_per_page=50
         )
-        return render('group/read')
+        return render('group/read.html')
 
     def new(self):
         record = model.Group
@@ -55,7 +54,7 @@ class GroupController(BaseController):
 
         fs = ckan.forms.get_group_fieldset('group_fs')
 
-        if request.params.has_key('commit'):
+        if request.params.has_key('save'):
             # needed because request is nested
             # multidict which is read only
             params = dict(request.params)
@@ -65,9 +64,10 @@ class GroupController(BaseController):
             except ValidationException, error:
                 fs = error.args[0]
                 c.form = self._render_edit_form(fs)
-                return render('group/edit')
+                return render('group/edit.html')
             # do not use groupname from id as may have changed
             c.groupname = c.fs.name.value
+            c.grouptitle = c.fs.title.value
             group = model.Group.by_name(c.groupname)
             assert group
             admins = []
@@ -90,7 +90,7 @@ class GroupController(BaseController):
             data = ckan.forms.edit_group_dict(ckan.forms.get_group_dict(), request.params)
             fs = fs.bind(data=data, session=model.Session)
         c.form = self._render_edit_form(fs)
-        return render('group/new')
+        return render('group/new.html')
 
     def edit(self, id=None): # allow id=None to allow posting
         c.error = ''
@@ -101,13 +101,14 @@ class GroupController(BaseController):
         if not am_authz:
             abort(401, gettext('User %r not authorized to edit %r') % (c.user, id))
 
-        if not 'commit' in request.params:
+        if not 'save' in request.params:
             c.group = group
             c.groupname = group.name
+            c.grouptitle = group.title
             
             fs = ckan.forms.get_group_fieldset('group_fs').bind(c.group)
             c.form = self._render_edit_form(fs)
-            return render('group/edit')
+            return render('group/edit.html')
         else:
             # id is the name (pre-edited state)
             c.groupname = id
@@ -119,10 +120,11 @@ class GroupController(BaseController):
                 self._update(c.fs, id, group.id)
                 # do not use groupname from id as may have changed
                 c.groupname = c.fs.name.value
+                c.grouptitle = c.fs.title.value
             except ValidationException, error:
                 fs = error.args[0]
                 c.form = self._render_edit_form(fs)
-                return render('group/edit')
+                return render('group/edit.html')
             pkgs = [model.Package.by_name(name) for name in request.params.getall('Group-packages-current')]
             group.packages = pkgs
             pkgids = request.params.getall('PackageGroup--package_id')
@@ -139,12 +141,13 @@ class GroupController(BaseController):
         if group is None:
             abort(404, gettext('Group not found'))
         c.groupname = group.name
+        c.grouptitle = group.title
 
         c.authz_editable = self.authorizer.am_authorized(c, model.Action.EDIT_PERMISSIONS, group)
         if not c.authz_editable:
             abort(401, gettext('Not authorized to edit authization for group'))
 
-        if 'commit' in request.params: # form posted
+        if 'save' in request.params: # form posted
             # needed because request is nested
             # multidict which is read only
             params = dict(request.params)
@@ -154,7 +157,7 @@ class GroupController(BaseController):
             except ValidationException, error:
                 # TODO: sort this out 
                 # fs = error.args[0]
-                # return render('group/authz')
+                # return render('group/authz.html')
                 raise
             # now do new roles
             newrole_user_id = request.params.get('GroupRole--user_id')
@@ -188,13 +191,13 @@ class GroupController(BaseController):
         fs = ckan.forms.get_authz_fieldset('group_authz_fs').bind(group.roles)
         c.form = fs.render()
         c.new_roles_form = ckan.forms.get_authz_fieldset('new_group_roles_fs').render()
-        return render('group/authz')
+        return render('group/authz.html')
 
     def _render_edit_form(self, fs):
         # errors arrive in c.error and fs.errors
         c.fieldset = fs
         c.fieldset2 = ckan.forms.get_group_fieldset('new_package_group_fs')
-        return render('group/edit_form')
+        return render('group/edit_form.html')
 
     def _update(self, fs, group_name, group_id):
         '''
