@@ -107,16 +107,22 @@ class Data(object):
         '''Munges the name field in case it is not to spec.'''
         return self._munge(input_name.replace(' ', '').replace('.', '_').replace('&', 'and'))
 
-    def _parse_tags(self, tags_str):
-        tag_list = re.split(',\s?|\s', tags_str)
-        return [schema_gov.tag_munge(tag_name) for tag_name in tag_list]
-
+    def _tidy_url(self, url):
+        if url and not url.startswith('http') and not url.startswith('webcal:'):
+            if url.startswith('www.'):
+                url = url.replace('www.', 'http://www.')
+            else:
+                print "Warning: URL doesn't start with http: %s" % url
+        return url
+                
     def _load_line_into_db(self, _dict, line_index):
         # Create package
-        rev = self._new_revision()
         name = self._name_munge(_dict['name'])
         title = _dict['title']
-        url = _dict['url']
+        if not (name and title):
+            return
+        rev = self._new_revision()
+        url = self._tidy_url(_dict['url'])
         notes = _dict['notes']
 
         if self._resources.has_key(name):
@@ -132,11 +138,13 @@ class Data(object):
             if split_char in _dict['download url']:
                 for url_ in _dict['download url'].split(split_char):
                     if url_.strip():
+                        url_ = self._tidy_url(url_)
                         resources.append({'url':url_, 'description':description, 'format':format})
                 multiple_urls = True
                 break
         if not multiple_urls and _dict['download url']:
-            resources.append({'url':_dict['download url'], 'description':description, 'format':format})
+            url_ = self._tidy_url(_dict['download url'])
+            resources.append({'url':url_, 'description':description, 'format':format})
         if resources:
             self._resources[name] = resources
             
@@ -149,10 +157,18 @@ class Data(object):
             _dict[field] = _dict['%s - other' % field] if \
                            _dict['%s - standard' % field] == 'Other (specify)' else \
                            _dict['%s - standard' % field]
-        license_id = license_map.get(_dict['licence'], '')
+
+        license_id = license_map.get(_dict['licence'].strip(), '')
+        if not license_id and ';' in _dict['licence']:
+            license_parts = _dict['licence'].split(';')
+            for i, license_part in enumerate(license_parts):
+                license_id = license_map.get(license_part.strip(), '')
+                if license_id:
+                    notes += '\n\nLicence detail: %s' % _dict['licence']
+                    break
         if not license_id:
-            print 'Warning: license not recognised: %s. Defaulting to UK Crown Copyright.' % _dict['licence']
-            license_name = u'ukcrown'
+            license_id = license_map[u'UK Crown Copyright with data.gov.uk rights']
+            print 'Warning: license not recognised: "%s". Defaulting to: %s.' % (_dict['licence'], license_id)
 
         # extras
         extras_dict = {}
@@ -169,12 +185,12 @@ class Data(object):
         for column in ['date released', 'date updated']:
             try:
                 val = field_types.DateType.form_to_db(_dict[column])
-            except TypeError, e:
+            except field_types.DateConvertError, e:
                 print "WARNING: Value for column '%s' of '%s' is not understood as a date format." % (column, _dict[column])
                 val = _dict[column]
             extras_dict[column.replace(' ', '_')] = val
 
-        given_tags = self._parse_tags(_dict['tags'])
+        given_tags = schema_gov.tags_parse(_dict['tags'])
             
         field_map = [
             ['co identifier'],
@@ -252,7 +268,7 @@ class Data(object):
             pkg.add_resource(resource['url'], format=resource['format'], description=resource['description'])
         pkg.notes=notes
         pkg.license_id = license_id
-        assert pkg.license
+        assert pkg.license, license_name
         if not existing_pkg:
             user = model.User.by_name(self._username)
 
@@ -323,6 +339,8 @@ class Data(object):
 license_map = {
     u'UK Crown Copyright with data.gov.uk rights':u'ukcrown-withrights',
     u'\xa9 HESA. Not core Crown Copyright.':u'hesa-withrights',
+    u'Local Authority copyright with data.gov.uk rights':u'localauth-withrights',
+    u'Local Authority Copyright with data.gov.uk rights':u'localauth-withrights',
     u'UK Crown Copyright':u'ukcrown',
     u'Crown Copyright':u'ukcrown', }
 #agencies_raw = ['Health Protection Agency', 'Office for National Statistics', 'Census', 'Performance Assessment Framework', 'Annual Population Survey', 'Annual Survey of Hours and Earnings', 'Business Registers Unit', 'UK Hydrographic Office', 'Defence Analytical Services and Advice', 'Housing and Communities Agency', 'Tenants Service Authority', 'Higher Education Statistics Agency']
