@@ -2,6 +2,7 @@ import cli
 
 class CreateTestData(cli.CkanCommand):
     '''Create test data in the database.
+    Tests can also delete the created objects easily with the delete() method.
 
     create-test-data         - annakarenina and warandpeace
     create-test-data search  - realistic data to test search
@@ -13,7 +14,17 @@ class CreateTestData(cli.CkanCommand):
     max_args = 1
     min_args = 0
     author = u'tester'
+
+    pkg_names = []
+    tag_names = []
+    group_names = set()
+    user_names = []
     
+    pkg_core_fields = ['name', 'title', 'version', 'url', 'notes',
+                       'author', 'author_email',
+                       'maintainer', 'maintainer_email',
+                       ]
+
     def command(self):
         self._load_config()
         self._setup_app()
@@ -57,13 +68,17 @@ class CreateTestData(cli.CkanCommand):
 
     @classmethod
     def create_arbitrary(self, package_dicts,
-                         relationships=[], extra_user_names=[]):
+                         relationships=[], extra_user_names=[],
+                         extra_group_names=[],
+                         commit_changesets=False):
+        assert isinstance(relationships, (list, tuple))
+        assert isinstance(extra_user_names, (list, tuple))
+        assert isinstance(extra_group_names, (list, tuple))
         import ckan.model as model
         model.Session.remove()
-        self.pkg_names = []
-        self.tag_names = []
-        self.group_names = set()
-        self.user_names = extra_user_names
+        new_user_names = extra_user_names
+        new_group_names = set()
+
         admins_list = [] # list of (package_name, admin_names)
         if package_dicts:
             rev = model.repo.new_revision() 
@@ -72,21 +87,23 @@ class CreateTestData(cli.CkanCommand):
             if isinstance(package_dicts, dict):
                 package_dicts = [package_dicts]
             for item in package_dicts:
-                pkg = model.Package(name=unicode(item['name']))
+                pkg_dict = {}
+                for field in self.pkg_core_fields:
+                    if item.has_key(field):
+                        pkg_dict[field] = unicode(item[field])
+                pkg = model.Package(**pkg_dict)
                 model.Session.add(pkg)
                 for attr, val in item.items():
                     if isinstance(val, str):
                         val = unicode(val)
                     if attr=='name':
                         continue                
-                    if attr in ['title', 'version', 'url', 'notes',
-                                'author', 'author_email',
-                                'maintainer', 'maintainer_email',
-                                ]:
-                        setattr(pkg, attr, unicode(val))
+                    if attr in self.pkg_core_fields:
+                        pass
                     elif attr == 'download_url':
                         pkg.add_resource(unicode(val))
                     elif attr == 'resources':
+                        assert isinstance(val, (list, tuple))
                         for res_dict in val:
                             pkg.add_resource(
                                 url=unicode(res_dict['url']),
@@ -110,12 +127,18 @@ class CreateTestData(cli.CkanCommand):
                                 model.Session.add(tag)    
                             pkg.tags.append(tag)
                     elif attr == 'groups':
-                        for group_name in val.split():
+                        if isinstance(val, (str, unicode)):
+                            group_names = val.split()
+                        elif isinstance(val, list):
+                            group_names = val
+                        else:
+                            raise NotImplementedError
+                        for group_name in group_names:
                             group = model.Group.by_name(group_name)
                             if not group:
                                 group = model.Group(name=group_name)
-                                self.group_names.add(group_name)
                                 model.Session.add(group)
+                                new_group_names.add(group_name)
                             pkg.groups.append(group)
                     elif attr == 'license':
                         pkg.license_id = val
@@ -126,26 +149,52 @@ class CreateTestData(cli.CkanCommand):
                     elif attr == 'admins':
                         assert isinstance(val, list)
                         admins_list.append((item['name'], val))
-                        for user in val:
-                            if user not in self.user_names:
-                                self.user_names.append(user)
+                        for user_name in val:
+                            if user_name not in new_user_names:
+                                new_user_names.append(user_name)
                     else:
                         raise NotImplementedError(attr)
                 self.pkg_names.append(item['name'])
                 model.setup_default_user_roles(pkg)
             model.repo.commit_and_remove()
 
-        for user_name in self.user_names:
-            user = model.User(name=unicode(user_name))
-            model.Session.add(user)
+        needs_commit = False
 
+        for group_name in extra_group_names:
+            group = model.Group(name=unicode(group_name))
+            model.Session.add(group)
+            new_group_names.add(group_name)
+            needs_commit = True
+
+        if needs_commit:
+            model.repo.commit_and_remove()
+            needs_commit = False
+
+        # create users that have been identified as being needed
+        for user_name in new_user_names:
+            if not model.User.by_name(unicode(user_name)):
+                user = model.User(name=unicode(user_name))
+                model.Session.add(user)
+                self.user_names.append(user_name)
+                needs_commit = True
+
+        # setup authz for admins
         for pkg_name, admins in admins_list:
             pkg = model.Package.by_name(unicode(pkg_name))
             admins = [model.User.by_name(unicode(user_name)) for user_name in self.user_names]
             model.setup_default_user_roles(pkg, admins)
+            needs_commit = True
 
-        for group_name in self.group_names:
+        # setup authz for groups just created
+        for group_name in new_group_names:
+            group = model.Group.by_name(unicode(group_name))
             model.setup_default_user_roles(group)
+            self.group_names.add(group_name)
+            needs_commit = True
+
+        if needs_commit:
+            model.repo.commit_and_remove()
+            needs_commit = False
 
         if relationships:
             rev = model.repo.new_revision() 
@@ -157,11 +206,16 @@ class CreateTestData(cli.CkanCommand):
             for subject_name, relationship, object_name in relationships:
                 pkg(subject_name).add_relationship(
                     unicode(relationship), pkg(object_name))
+                needs_commit = True
 
             model.repo.commit_and_remove()
-    
+        
+        if commit_changesets:
+            from ckan.model.changeset import ChangesetRegister
+            changeset_ids = ChangesetRegister().commit()
+
     @classmethod
-    def create(self):
+    def create(self, commit_changesets=False):
         import ckan.model as model
         model.Session.remove()
         rev = model.repo.new_revision()
@@ -206,7 +260,8 @@ class CreateTestData(cli.CkanCommand):
 Foreign characters:
 u with umlaut \xfc
 66-style quote \u201c
-
+foreign word: th\xfcmb
+ 
 Needs escaping:
 left arrow <
 
@@ -238,7 +293,8 @@ left arrow <
                              description=u'Roger likes these books.')
         for obj in [david, roger]:
             model.Session.add(obj)
-        self.group_names = (u'david', u'roger')
+        self.group_names.add(u'david')
+        self.group_names.add(u'roger')
         david.packages = [pkg1, pkg2]
         roger.packages = [pkg1]
         # authz
@@ -265,10 +321,31 @@ left arrow <
 
         model.repo.commit_and_remove()
 
+        if commit_changesets:
+            from ckan.model.changeset import ChangesetRegister
+            changeset_ids = ChangesetRegister().commit()
+
+    @classmethod
+    def flag_for_deletion(self, pkg_names=[], tag_names=[], group_names=[],
+                          user_names=[]):
+        '''If you create a domain object manually in your test then you
+        can name it here (flag it up) and it will be deleted when you next
+        call CreateTestData.delete().'''
+        self.pkg_names.extend(pkg_names)
+        self.tag_names.extend(tag_names)
+        self.group_names = self.group_names.union(set(group_names))
+        self.user_names.extend(user_names)
 
     @classmethod
     def delete(self):
+        '''Purges packages etc. that were created by this class.'''
         import ckan.model as model
+        for pkg_name in self.pkg_names:
+            pkg = model.Package.by_name(unicode(pkg_name))
+            if pkg:
+                sql = "DELETE FROM package_search WHERE package_id='%s'" % pkg.id
+                model.Session.execute(sql)
+        model.repo.commit_and_remove()
         for pkg_name in self.pkg_names:
             pkg = model.Package.by_name(unicode(pkg_name))
             if pkg:
@@ -279,6 +356,8 @@ left arrow <
                 tag.purge()
         revs = model.Session.query(model.Revision).filter_by(author=self.author)
         for rev in revs:
+            for pkg in rev.packages:
+                pkg.purge()
             model.Session.delete(rev)
         for group_name in self.group_names:
             group = model.Group.by_name(unicode(group_name))
@@ -295,20 +374,24 @@ left arrow <
 search_items = [{'name':'gils',
               'title':'Government Information Locator Service',
               'url':'',
-              'tags':'registry  country-usa  government  federal  gov  workshop-20081101',
+              'tags':'registry  country-usa  government  federal  gov  workshop-20081101 penguin',
               'groups':'ukgov test1 test2 penguin',
               'license':'gpl-3.0',
-              'notes':'''From <http://www.gpoaccess.gov/gils/about.html>
+              'notes':u'''From <http://www.gpoaccess.gov/gils/about.html>
               
 > The Government Information Locator Service (GILS) is an effort to identify, locate, and describe publicly available Federal
-> Because this collection is decentralized, the GPO''',
+> Because this collection is decentralized, the GPO
+
+Foreign word:
+u with umlaut th\xfcmb
+''',
               'extras':{'date_released':'2008'},
               },
              {'name':'us-gov-images',
               'title':'U.S. Government Photos and Graphics',
               'url':'http://www.usa.gov/Topics/Graphics.shtml',
               'download_url':'http://www.usa.gov/Topics/Graphics.shtml',
-              'tags':'images  graphics  photographs  photos  pictures  us  usa  america  history  wildlife  nature  war  military  todo-split  gov',
+              'tags':'images  graphics  photographs  photos  pictures  us  usa  america  history  wildlife  nature  war  military  todo-split  gov penguin',
               'groups':'ukgov test1 penguin',
               'license':'other-open',
               'notes':'''## About
@@ -331,12 +414,15 @@ Collection of links to different US image collections in the public domain.
 
 1.8 million pages of U.S. case law available with no restrictions. From the [README](http://bulk.resource.org/courts.gov/0_README.html):
 
-> This file is  http://bulk.resource.org/courts.gov/0_README.html and was last revised''',
+> This file is  http://bulk.resource.org/courts.gov/0_README.html and was last revised.
+
+penguin
+''',
               'extras':{'date_released':'2007-06'},
               },
              {'name':'uk-government-expenditure',
               'title':'UK Government Expenditure',
-              'tags':'workshop-20081101  uk  gov  expenditure  finance  public  funding',
+              'tags':'workshop-20081101  uk  gov  expenditure  finance  public  funding penguin',
               'groups':'ukgov penguin',              
               'notes':'''Discussed at [Workshop on Public Information, 2008-11-02](http://okfn.org/wiki/PublicInformation).
 
@@ -347,7 +433,7 @@ Overview is available in Red Book, or Financial Statement and Budget Report (FSB
               'title':'Sweden - Government Offices of Sweden - Publications',
               'url':'http://www.sweden.gov.se/sb/d/574',
               'groups':'penguin',              
-              'tags':'country-sweden  format-pdf  access-www  documents  publications  government  eutransparency',
+              'tags':'country-sweden  format-pdf  access-www  documents  publications  government  eutransparency penguin',
               'license':'',
               'notes':'''### About
 
@@ -363,7 +449,7 @@ Not clear.''',
               'groups':'penguin',              
               'url':'http://www.opengov.se/',
               'download_url':'http://www.opengov.se/data/open/',
-              'tags':'country-sweden  government  data',
+              'tags':'country-sweden  government  data penguin',
               'license':'cc-by-sa',
               'notes':'''### About
 
