@@ -1,14 +1,18 @@
 import meta
 from core import *
+from package import *
+from tag import *
+from package_mapping import *
 from user import user_table, User
-from group import group_table, Group, PackageGroup
-from full_search import package_search_table
+from group import *
+from search_index import *
 from authz import *
 from extras import *
 from resource import *
 from rating import *
 from package_relationship import PackageRelationship
 from changeset import Changeset, Change, Changemask
+from notifier import *
 
 import ckan.migration
 
