@@ -2,7 +2,8 @@ from meta import *
 from types import make_uuid
 import vdm.sqlalchemy
 
-from core import DomainObject, Package, Revision, State
+from core import *
+from package import *
 from types import JsonType
 
 __all__ = ['PackageExtra', 'package_extra_table', 'PackageExtraRevision']
@@ -32,7 +33,9 @@ mapper(PackageExtra, package_extra_table, properties={
         )
     },
     order_by=[package_extra_table.c.package_id, package_extra_table.c.key],
-    extension = vdm.sqlalchemy.Revisioner(extra_revision_table)
+    extension=[vdm.sqlalchemy.Revisioner(extra_revision_table),
+               notifier.NotifierMapperTrigger(),
+               ],
 )
 
 vdm.sqlalchemy.modify_base_object_mapper(PackageExtra, Revision, State)
