@@ -12,6 +12,8 @@ import os
 import sys
 import re
 from unittest import TestCase
+from nose.tools import assert_equal
+import time
 
 import sgmllib
 import pkg_resources
@@ -21,10 +23,18 @@ from paste.deploy import loadapp
 from routes import url_for
 
 from ckan.lib.create_test_data import CreateTestData
+from ckan.lib import search
+
+import resource, socket
+
+if 'ubik.local' == socket.gethostname():
+    resource.setrlimit(resource.RLIMIT_NOFILE, (500,-1))
+
 
 __all__ = ['url_for',
-        'TestController',
-        'CreateTestData',
+           'TestController',
+           'CreateTestData',
+           'TestSearchIndexer',
         ]
 
 here_dir = os.path.dirname(os.path.abspath(__file__))
@@ -35,10 +45,15 @@ pkg_resources.working_set.add_entry(conf_dir)
 pkg_resources.require('Paste')
 pkg_resources.require('PasteScript')
 
-test_file = os.path.join(conf_dir, 'test.ini')
+def config_abspath(file_path):
+    if os.path.isabs(file_path):
+        return file_path
+    return os.path.join(conf_dir, file_path)
+
+config_path = config_abspath('test.ini')
 
 cmd = paste.script.appinstall.SetupCommand('setup-app')
-cmd.run([test_file])
+cmd.run([config_path])
 
 import ckan.model as model
 model.repo.rebuild_db()
@@ -57,12 +72,25 @@ class Stripper(sgmllib.SGMLParser):
     def handle_data(self, data):
         self.str += data
 
+
 class TestController(object):
 
     def __init__(self, *args, **kwargs):
         wsgiapp = loadapp('config:test.ini', relative_to=conf_dir)
         self.app = paste.fixture.TestApp(wsgiapp)
 
+    @classmethod
+    def create_package(self, **kwds):
+        CreateTestData.create_arbitrary(package_dicts=[kwds])
+
+    @classmethod
+    def create_user(self, **kwds):
+        user = model.User(name=kwds['name'])             
+        model.Session.add(user)
+        model.Session.commit()
+        model.Session.remove()
+        return user
+
     def create_100_packages(self):
         rev = model.repo.new_revision()
         for i in range(0,100):
@@ -71,6 +99,23 @@ class TestController(object):
         model.Session.commit()
         model.Session.remove()
 
+    @classmethod
+    def get_package_by_name(self, package_name):
+        return model.Package.by_name(package_name)
+
+    def get_group_by_name(self, group_name):
+        return model.Group.by_name(group_name)
+
+    def get_user_by_name(self, name):
+        return model.User.by_name(name)
+
+    @classmethod
+    def purge_package_by_name(self, package_name):
+        package = self.get_package_by_name(package_name)
+        if package:
+            package.purge()
+        model.repo.commit_and_remove()
+
     def purge_100_packages(self):
         listRegister = self.get_model().packages
         for i in range(0,100):
@@ -80,6 +125,19 @@ class TestController(object):
         model.Session.commit()
         model.Session.remove()
 
+    @classmethod
+    def purge_packages(self, pkg_names):
+        for pkg_name in pkg_names:
+            pkg = model.Package.by_name(unicode(pkg_name))
+            if pkg:
+                pkg.purge()
+        model.repo.commit_and_remove()
+
+    @classmethod
+    def purge_all_packages(self):
+        all_pkg_names = [pkg.name for pkg in model.Session.query(model.Package)]
+        self.purge_packages(all_pkg_names)
+
     def create_200_tags(self):
         for i in range(0,200):
             name = u"testtag%s" % i
@@ -180,3 +238,72 @@ class TestController(object):
                 return # found it
         # didn't find it
         assert 0, "Couldn't find %s in html. Closest matches were:\n%s" % (', '.join(["'%s'" % html.encode('utf8') for html in html_to_find]), '\n'.join([tag.encode('utf8') for tag in partly_matching_tags]))
+
+    def assert_equal(self, *args, **kwds):
+        assert_equal(*args, **kwds)
+
+    @property
+    def war(self):
+        return self.get_package_by_name(u'warandpeace')
+
+    @property
+    def anna(self):
+        return self.get_package_by_name(u'annakarenina')
+
+    def _system(self, cmd):
+        import commands
+        (status, output) = commands.getstatusoutput(cmd)
+        if status:
+            raise Exception, "Couldn't execute cmd: %s: %s" % (cmd, output)
+
+    def _paster(self, cmd, config_path_rel):
+        from pylons import config
+        config_path = os.path.join(config['here'], config_path_rel)
+        self._system('paster --plugin ckan %s --config=%s' % (cmd, config_path))
+
+    def _recreate_ckan_server_testdata(self, config_path):
+        self._paster('db clean', config_path)
+        self._paster('db init', config_path)
+        self._paster('create-test-data', config_path)
+
+    def _start_ckan_server(self, config_file='test.ini'):
+        config_path = config_abspath(config_file)
+        import subprocess
+        process = subprocess.Popen(['paster', 'serve', config_path])
+        return process
+
+    def _wait_for_url(self, url, timeout=15):
+        for i in range(int(timeout)):
+            import urllib2
+            import time
+            try:
+                response = urllib2.urlopen('http://127.0.0.1:5000/')
+            except urllib2.URLError:
+                pass 
+                time.sleep(1)
+            else:
+                break
+
+    def _stop_ckan_server(self, process): 
+        pid = process.pid
+        pid = int(pid)
+        if os.system("kill -9 %d" % pid):
+            raise Exception, "Can't kill foreign CKAN instance (pid: %d)." % pid
+
+
+class TestSearchIndexer:
+    worker = None
+    
+    def __init__(self):
+        TestSearchIndexer.worker = search.SearchIndexWorker(search.get_backend(backend='sql'))
+        TestSearchIndexer.worker.clear_queue()
+        self.worker.consumer.close()
+
+    @classmethod
+    def index(cls):
+        message = cls.worker.consumer.fetch()
+        while message is not None:
+            cls.worker.async_callback(message.payload, message)
+            message = cls.worker.consumer.fetch()
+        cls.worker.consumer.close()        
+
