@@ -1,9 +1,8 @@
-import simplejson
-
 import ckan.model as model
 from ckan.tests import *
 from ckan.lib.base import *
 import ckan.authz as authz
+from ckan.lib.helpers import json
 
 class TestUsage(TestController):
     deleted = model.State.DELETED
@@ -93,8 +92,10 @@ class TestUsage(TestController):
 
     @classmethod
     def setup_class(self):
+        indexer = TestSearchIndexer()
         self._create_test_data()
         model.Session.remove()
+        indexer.index()
 
     @classmethod
     def teardown_class(self):
@@ -125,7 +126,7 @@ class TestUsage(TestController):
         # Test action on REST
         if action == model.Action.EDIT:
             offset = '/api/rest/%s/%s' % (entity, mode)
-            postparams = '%s=1' % simplejson.dumps({'title':u'newtitle'}, encoding='utf8')
+            postparams = '%s=1' % json.dumps({'title':u'newtitle'}, encoding='utf8')
             func = self.app.post
         elif action == model.Action.READ:
             offset = '/api/rest/%s/%s' % (entity, mode)
@@ -239,11 +240,11 @@ class TestUsage(TestController):
         assert not model.Package.by_name(u'annakarenina')
         offset = url_for(controller='package', action='new')
         res = self.app.get(offset, extra_environ={'REMOTE_USER': user.name.encode('utf8')})
-        assert 'Packages - New' in res
-        fv = res.forms[0]
+        assert 'New - Data Packages' in res
+        fv = res.forms['package-edit']
         prefix = 'Package--'
         fv[prefix + 'name'] = u'annakarenina'
-        res = fv.submit('commit', extra_environ={'REMOTE_USER': user.name.encode('utf8')})
+        res = fv.submit('save', extra_environ={'REMOTE_USER': user.name.encode('utf8')})
 
         # check user is admin
         pkg = model.Package.by_name(u'annakarenina')
