@@ -26,7 +26,7 @@ class TestHomeController(TestController):
         offset = url_for('license')
         res = self.app.get(offset)
         print str(res)
-        assert 'The code that runs CKAN is open-source' in res
+        assert 'The CKAN code that runs this site is open-source' in res
 
     def test_guide(self):
         url = url_for('guide')
@@ -35,10 +35,10 @@ class TestHomeController(TestController):
     def test_search_packages(self):
         offset = url_for('home')
         res = self.app.get(offset)
-        form = res.forms[0]
+        form = res.forms['package-search']
         form['q'] =  'anna'
         results_page = form.submit()
-        assert 'Search packages' in results_page, results_page
+        assert 'Search - Data Packages' in results_page, results_page
         assert '>0<' in results_page, results_page
 
     # DISABLED because this is not on home page anymore
